aboutsummaryrefslogtreecommitdiffstatshomepage
path: root/src/noise.h
diff options
context:
space:
mode:
authorJason A. Donenfeld <Jason@zx2c4.com>2017-05-24 03:35:35 +0200
committerJason A. Donenfeld <Jason@zx2c4.com>2017-05-30 18:07:28 +0200
commita6722232fbc33cecf987ccac68324b7d2f6867c9 (patch)
tree14875b93a6850787569fe75ad707ade1456f653d /src/noise.h
parentnoise: no need to store ephemeral public key (diff)
downloadwireguard-monolithic-historical-a6722232fbc33cecf987ccac68324b7d2f6867c9.tar.xz
wireguard-monolithic-historical-a6722232fbc33cecf987ccac68324b7d2f6867c9.zip
noise: precompute static-static ECDH operation
Diffstat (limited to 'src/noise.h')
-rw-r--r--src/noise.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/src/noise.h b/src/noise.h
index ccceb6b..5e4d9af 100644
--- a/src/noise.h
+++ b/src/noise.h
@@ -76,9 +76,9 @@ struct noise_handshake {
struct noise_static_identity *static_identity;
u8 ephemeral_private[NOISE_PUBLIC_KEY_LEN];
-
u8 remote_static[NOISE_PUBLIC_KEY_LEN];
u8 remote_ephemeral[NOISE_PUBLIC_KEY_LEN];
+ u8 precomputed_static_static[NOISE_PUBLIC_KEY_LEN];
u8 preshared_key[NOISE_SYMMETRIC_KEY_LEN];
@@ -88,7 +88,7 @@ struct noise_handshake {
u8 latest_timestamp[NOISE_TIMESTAMP_LEN];
__le32 remote_index;
/* Protects all members except the immutable (after noise_peer_init): remote_static, static_identity */
struct rw_semaphore lock;
};
@@ -101,7 +101,7 @@ struct message_data;
struct message_handshake_cookie;
void noise_init(void);
-void noise_handshake_init(struct noise_handshake *handshake, struct noise_static_identity *static_identity, const u8 peer_public_key[NOISE_PUBLIC_KEY_LEN], const u8 peer_preshared_key[NOISE_SYMMETRIC_KEY_LEN], struct wireguard_peer *peer);
+bool noise_handshake_init(struct noise_handshake *handshake, struct noise_static_identity *static_identity, const u8 peer_public_key[NOISE_PUBLIC_KEY_LEN], const u8 peer_preshared_key[NOISE_SYMMETRIC_KEY_LEN], struct wireguard_peer *peer);
void noise_handshake_clear(struct noise_handshake *handshake);
void noise_keypair_put(struct noise_keypair *keypair);
struct noise_keypair *noise_keypair_get(struct noise_keypair *keypair);
@@ -109,6 +109,7 @@ void noise_keypairs_clear(struct noise_keypairs *keypairs);
bool noise_received_with_keypair(struct noise_keypairs *keypairs, struct noise_keypair *received_keypair);
void noise_set_static_identity_private_key(struct noise_static_identity *static_identity, const u8 private_key[NOISE_PUBLIC_KEY_LEN]);
+int noise_precompute_static_static(struct wireguard_peer *peer, void *ctx);
bool noise_handshake_create_initiation(struct message_handshake_initiation *dst, struct noise_handshake *handshake);
struct wireguard_peer *noise_handshake_consume_initiation(struct message_handshake_initiation *src, struct wireguard_device *wg);
@@ -88,7 +88,7 @@ struct noise_handshake {
u8 latest_timestamp[NOISE_TIMESTAMP_LEN];
__le32 remote_index;
- /* Protects all members except the immutable (after noise_peer_init): remote_static, static_identity */
+ /* Protects all members except the immutable (after noise_handshake_init): remote_static, precomputed_static_static, static_identity */
struct rw_semaphore lock;
};